@@ -39,8 +39,8 @@
 
 #define P_(string) string
 
-static void gtk_plot_box_class_init 	(GtkPlotBoxClass *klass);
-static void gtk_plot_box_init 		(GtkPlotBox *data);
+static void gtk_plot_box_class_init 	(GtkPlotBoxClass *klass, gpointer unused);
+static void gtk_plot_box_init 		(GtkPlotBox *data, gpointer unused);
 static void gtk_plot_box_set_property   (GObject *object,
                                          guint prop_id,
                                          const GValue *value,
@@ -91,7 +91,7 @@ gtk_plot_box_get_type (void)
 }
 
 static void
-gtk_plot_box_class_init (GtkPlotBoxClass *klass)
+gtk_plot_box_class_init (GtkPlotBoxClass *klass, gpointer unused)
 {
   GtkPlotDataClass *data_class;
   GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
@@ -135,6 +135,8 @@ gtk_plot_box_set_property (GObject      *object,
       case ARG_ORIENTATION:
         data->orientation  = g_value_get_enum(value);
         break;
+      default:
+	break;
     }
 }
 
@@ -161,7 +163,7 @@ gtk_plot_box_get_property (GObject      *object,
 
 
 static void
-gtk_plot_box_init (GtkPlotBox *dataset)
+gtk_plot_box_init (GtkPlotBox *dataset, gpointer unused)
 {
   GdkRGBA black, white;
 
@@ -260,7 +262,7 @@ gtk_plot_box_draw_symbol(GtkPlotData *dataset,
             gtk_plot_get_pixel(plot, x, y, &px0, &py0);
             gtk_plot_get_pixel(plot, x, z, &px1, &py1);
             width = roundint(dataset->symbol.size * m);
-            height = abs(py1 - py0);
+            height = fabs(py1 - py0);
 
             gtk_plot_get_pixel(plot, x, z + dy, &eu_x, &eu_y);
             gtk_plot_get_pixel(plot, x, y - dy, &ed_x, &ed_y);
@@ -324,6 +326,9 @@ gtk_plot_box_draw_symbol(GtkPlotData *dataset,
             gtk_plot_pc_draw_lines(plot->pc, errbar, 2);
 
             break;
+
+	  default:
+	    break;
         }
       }
 
@@ -346,6 +351,8 @@ gtk_plot_box_draw_symbol(GtkPlotData *dataset,
           height = roundint(dataset->symbol.size * m);
           y1 = py0 - height / 2;
           break;
+	default:
+	  break;
       }
 
       if(dataset->symbol.symbol_style == GTK_PLOT_SYMBOL_OPAQUE){
@@ -374,6 +381,8 @@ gtk_plot_box_draw_symbol(GtkPlotData *dataset,
         case GTK_ORIENTATION_HORIZONTAL:    
           gtk_plot_pc_draw_line(plot->pc, px, py-height/2, px, py+height/2); 
           break;
+	default:
+	  break;
       }
 
     }  
@@ -409,7 +418,7 @@ gtk_plot_box_draw_legend(GtkPlotData *data, gint x, gint y)
   if(data->legend)
     legend.text = data->legend;
   else
-    legend.text = "";
+    legend.text = (char *)"";
 
   gtk_plot_text_get_size(legend.text, legend.angle, legend.font,
                          roundint(legend.height * m), 
