@@ -41,8 +41,8 @@
 #include "gtkplotcanvas.h"
 #include <pango/pango.h>
 
-static void gtk_plot_cairo_init                       (GtkPlotCairo *pc);
-static void gtk_plot_cairo_class_init                 (GtkPlotCairoClass *klass);
+static void gtk_plot_cairo_init                       (GtkPlotCairo *pc, gpointer unused);
+static void gtk_plot_cairo_class_init                 (GtkPlotCairoClass *klass, gpointer unused);
 static void gtk_plot_cairo_finalize                   (GObject *object);
 static gboolean gtk_plot_cairo_real_init              (GtkPlotPC *pc);
 static void gtk_plot_cairo_set_viewport               (GtkPlotPC *pc,
@@ -144,7 +144,7 @@ gtk_plot_cairo_get_type (void)
 }
 
 static void
-gtk_plot_cairo_init (GtkPlotCairo *pc)
+gtk_plot_cairo_init (GtkPlotCairo *pc, gpointer unused)
 {
   pc->cairo = NULL;
   /*
@@ -183,7 +183,7 @@ gtk_plot_cairo_init (GtkPlotCairo *pc)
 
 
 static void
-gtk_plot_cairo_class_init (GtkPlotCairoClass *klass)
+gtk_plot_cairo_class_init (GtkPlotCairoClass *klass, gpointer unused)
 {
   GObjectClass *gobject_class;
   GtkPlotPCClass *pc_class;
@@ -409,12 +409,13 @@ gtk_plot_cairo_set_dash                               (GtkPlotPC *pc,
                                                        gint num_values)
 {
   cairo_t *cairo = GTK_PLOT_CAIRO(pc)->cairo; /* Shortcut */
-  if (!cairo)
-    return;
   gchar list[] = {'\0','\1','\2','\3','\4','\5','\6','\7'};
   double dash[1000];
   gint i;
 
+  if (!cairo)
+    return;
+
   if(num_values == 0){
     return;
   }
@@ -781,6 +782,8 @@ gtk_plot_cairo_draw_string                        (GtkPlotPC *pc,
         case 270:
             tx -= descent;
             break;
+	default:
+	    break;
       }
       old_tx = tx;
       old_ty = ty;
@@ -808,6 +811,8 @@ gtk_plot_cairo_draw_string                        (GtkPlotPC *pc,
             old_tx -= descent;
             old_ty -= height;
             break;
+	default:
+	    break;
       }
       break;
     case GTK_JUSTIFY_CENTER:
@@ -837,6 +842,8 @@ gtk_plot_cairo_draw_string                        (GtkPlotPC *pc,
             old_tx -= descent;
             old_ty -= height / 2.;
             break;
+	default:
+	    break;
       }
   }
 
@@ -999,7 +1006,7 @@ gtk_plot_cairo_draw_string                        (GtkPlotPC *pc,
        case 'b':
            if (lastchar) {
              const gchar *aux2 = lastchar;
-             gint i = aux2 - g_utf8_prev_char(lastchar);
+             i = aux2 - g_utf8_prev_char(lastchar);
              pango_layout_set_text(layout, lastchar, i);
              pango_layout_get_extents(layout, NULL, &rect);
              x -= sign_x*PANGO_PIXELS(rect.width);
@@ -1073,6 +1080,7 @@ gtk_plot_cairo_draw_string                        (GtkPlotPC *pc,
                          old_tx + width + border_space,
                          old_ty - border_space + shadow_width,
                          shadow_width, height + 2 * border_space);
+      /* FALLTHRU */
     case GTK_PLOT_BORDER_LINE:
       gtk_plot_pc_draw_rectangle(pc,
                          FALSE,
@@ -1096,12 +1104,13 @@ static void gtk_plot_cairo_draw_pixmap                (GtkPlotPC *pc,
                                                       gdouble scale_x, 
                                                       gdouble scale_y)
 {
-  if (!GTK_PLOT_CAIRO(pc)->cairo)
-    return;
-
   cairo_surface_t *image_surface = NULL;
   cairo_surface_t *mask_surface = NULL;
   cairo_t *cr;
+
+  if (!GTK_PLOT_CAIRO(pc)->cairo)
+    return;
+
 /* TODO: USE MASK */
 
   image_surface = cairo_image_surface_create(CAIRO_FORMAT_RGB24, (width-xsrc)*scale_x, (height-ysrc)*scale_y);
