@@ -77,8 +77,8 @@ enum {
   ARG_CHILD_SELECTION_MODE,
 };
 
-static void gtk_plot_canvas_class_init 		(GtkPlotCanvasClass *klass);
-static void gtk_plot_canvas_init 		(GtkPlotCanvas *plot_canvas);
+static void gtk_plot_canvas_class_init 		(GtkPlotCanvasClass *klass, gpointer unused);
+static void gtk_plot_canvas_init 		(GtkPlotCanvas *plot_canvas, gpointer unused);
 static void gtk_plot_canvas_set_property        (GObject *object,
                                                  guint            prop_id,
                                                  const GValue          *value,
@@ -87,8 +87,8 @@ static void gtk_plot_canvas_get_property        (GObject *object,
                                                  guint            prop_id,
                                                  GValue          *value,
                                                  GParamSpec      *pspec);
-static void gtk_plot_canvas_child_class_init 	(GtkPlotCanvasChildClass *klass);
-static void gtk_plot_canvas_child_init 		(GtkPlotCanvasChild *child);
+static void gtk_plot_canvas_child_class_init 	(GtkPlotCanvasChildClass *klass, gpointer unused);
+static void gtk_plot_canvas_child_init 		(GtkPlotCanvasChild *child, gpointer unused);
 static void gtk_plot_canvas_child_set_property  (GObject *object,
                                                  guint            prop_id,
                                                  const GValue          *value,
@@ -130,8 +130,6 @@ static gboolean gtk_plot_canvas_draw            (GtkWidget *widget,
                                                  cairo_t *cr);
 static void gtk_plot_canvas_create_pixmap       (GtkWidget *widget, 
                                                  gint width, gint height);
-static void gtk_plot_canvas_child_draw		(GtkPlotCanvas *canvas,
-						 GtkPlotCanvasChild *child);
 static void gtk_plot_canvas_child_draw_selection(cairo_t *cr,
 						 GtkPlotCanvas *canvas,
 						 GtkPlotCanvasChild *child,
@@ -229,7 +227,7 @@ gtk_plot_canvas_child_get_type (void)
 }
 
 static void
-gtk_plot_canvas_child_class_init (GtkPlotCanvasChildClass *klass)
+gtk_plot_canvas_child_class_init (GtkPlotCanvasChildClass *klass, gpointer unused)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
 
@@ -432,6 +430,8 @@ gtk_plot_canvas_child_get_property (GObject      *object,
     case ARG_CHILD_SELECTION_MODE:
       g_value_set_int(value, child->mode);
       break;
+    default:
+      break;
   }
 }
 
@@ -477,11 +477,13 @@ gtk_plot_canvas_child_set_property (GObject      *object,
     case ARG_CHILD_SELECTION_MODE:
       child->mode = g_value_get_int(value); 
       break;
+    default:
+      break;
   }
 }
 
 static void
-gtk_plot_canvas_child_init(GtkPlotCanvasChild *child)
+gtk_plot_canvas_child_init(GtkPlotCanvasChild *child, gpointer unused)
 {
   child->flags = GTK_PLOT_CANVAS_CAN_MOVE | 
                  GTK_PLOT_CANVAS_CAN_RESIZE;
@@ -495,7 +497,7 @@ gtk_plot_canvas_child_init(GtkPlotCanvasChild *child)
 }
 
 static void
-gtk_plot_canvas_class_init (GtkPlotCanvasClass *klass)
+gtk_plot_canvas_class_init (GtkPlotCanvasClass *klass, gpointer unused)
 {
   GtkWidgetClass *object_class;
   GtkWidgetClass *widget_class;
@@ -817,6 +819,8 @@ gtk_plot_canvas_get_property (GObject      *object,
     case ARG_CANVAS_TRANSPARENT:
       g_value_set_boolean(value, canvas->transparent);
       break;
+    default:
+      break;
   }
 }
 
@@ -858,11 +862,13 @@ gtk_plot_canvas_set_property (GObject      *object,
     case ARG_CANVAS_TRANSPARENT:
       canvas->transparent = g_value_get_boolean(value);
       break;
+    default:
+      break;
   }
 }
 
 static void
-gtk_plot_canvas_init (GtkPlotCanvas *plot_canvas)
+gtk_plot_canvas_init (GtkPlotCanvas *plot_canvas, gpointer unused)
 {
   GtkWidget *widget;
   GdkRGBA color, black, white;
@@ -1157,6 +1163,12 @@ gtk_plot_canvas_paint (GtkPlotCanvas *canvas)
   gtk_plot_pc_leave(canvas->pc);
 }
 
+static void
+queue_draw_callback(GtkWidget *widget, gpointer data)
+{
+  gtk_widget_queue_draw(widget);
+}
+
 /**
  * gtk_plot_canvas_refresh:
  * @canvas: a #GtkPlotCanvas.
@@ -1172,7 +1184,7 @@ gtk_plot_canvas_refresh(GtkPlotCanvas *canvas)
   gtk_widget_queue_draw(GTK_WIDGET(canvas));
 
   gtk_container_foreach(GTK_CONTAINER(canvas),
-                        (GtkCallback) gtk_widget_queue_draw, NULL);
+                        queue_draw_callback, NULL);
 }
 
 static void
@@ -1345,6 +1357,7 @@ gtk_plot_canvas_motion (GtkWidget *widget, GdkEventMotion *event)
                     new_x = MIN(x, pivot_x);
                     new_width = abs(x - pivot_x);
                }
+	       /* FALLTHRU */
             case GTK_PLOT_CANVAS_TOP:
                if(canvas->active_item && canvas->active_item->flags & GTK_PLOT_CANVAS_CAN_RESIZE){
                     new_y = MIN(y, pivot_y);
@@ -1362,6 +1375,7 @@ gtk_plot_canvas_motion (GtkWidget *widget, GdkEventMotion *event)
                     new_x = MIN(x, pivot_x);
                     new_width = abs(x - pivot_x);
                }
+	       /* FALLTHRU */
             case GTK_PLOT_CANVAS_BOTTOM:
                if(canvas->active_item && canvas->active_item->flags & GTK_PLOT_CANVAS_CAN_RESIZE){
                     new_y = MIN(y, pivot_y);
@@ -2508,6 +2522,7 @@ gtk_plot_canvas_set_line_attributes(GtkPlotCanvas *canvas, GtkPlotLine line)
         gtk_plot_pc_set_lineattr(canvas->pc, line.line_width,
                                 1, 0, 0);
         gtk_plot_pc_set_dash(canvas->pc, 0, dash, 2);
+	break;
    case GTK_PLOT_LINE_DOT_DASH:
         gtk_plot_pc_set_lineattr(canvas->pc, line.line_width,
                                 1, 0, 0);
