@@ -53,8 +53,8 @@ enum{
   ARG_ARROW_STYLE
 };
 
-static void gtk_plot_canvas_line_init		(GtkPlotCanvasLine *line);
-static void gtk_plot_canvas_line_class_init	(GtkPlotCanvasChildClass *klass);
+static void gtk_plot_canvas_line_init		(GtkPlotCanvasLine *line, gpointer unused);
+static void gtk_plot_canvas_line_class_init	(GtkPlotCanvasChildClass *klass, gpointer unused);
 static void gtk_plot_canvas_line_draw_selection (cairo_t *cr,
 						 GtkPlotCanvas *canvas,
 						 GtkPlotCanvasChild *child,
@@ -125,7 +125,7 @@ gtk_plot_canvas_line_new (GtkPlotLineStyle style,
 }
 
 static void
-gtk_plot_canvas_line_init (GtkPlotCanvasLine *line)
+gtk_plot_canvas_line_init (GtkPlotCanvasLine *line, gpointer unused)
 {
   gdk_rgba_parse(&line->line.color, "black");
                                                     
@@ -140,7 +140,7 @@ gtk_plot_canvas_line_init (GtkPlotCanvasLine *line)
 }
 
 static void
-gtk_plot_canvas_line_class_init (GtkPlotCanvasChildClass *klass)
+gtk_plot_canvas_line_class_init (GtkPlotCanvasChildClass *klass, gpointer unused)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
 
@@ -327,6 +327,8 @@ gtk_plot_canvas_line_set_property (GObject      *object,
     case ARG_ARROW_STYLE:
       line->arrow_style = g_value_get_int(value);
       break;
+    default:
+      break;
   }
 }
 
@@ -369,6 +371,8 @@ gtk_plot_canvas_line_get_property (GObject      *object,
     case ARG_ARROW_STYLE:
       g_value_set_int(value, line->arrow_style);
       break;
+    default:
+      break;
   }
 }
 
@@ -419,6 +423,8 @@ gtk_plot_canvas_line_draw 		(GtkPlotCanvas *canvas,
          break;
        case GTK_PLOT_SYMBOL_FILLED:
          gtk_plot_pc_draw_polygon (canvas->pc, TRUE, arrow, 3);
+       default:
+	 break;
      }
   }
   if(line->arrow_mask & GTK_PLOT_CANVAS_ARROW_ORIGIN){
@@ -442,6 +448,8 @@ gtk_plot_canvas_line_draw 		(GtkPlotCanvas *canvas,
          break;
        case GTK_PLOT_SYMBOL_FILLED:
          gtk_plot_pc_draw_polygon (canvas->pc, TRUE, arrow, 3);
+       default:
+	 break;
      }
   }
 }
