@@ -64,8 +64,8 @@ typedef struct
   gint type;             /* one or two intersection points */ 
 } GtkPlotContourX;
 
-static void gtk_plot_csurface_class_init 	(GtkPlotCSurfaceClass *klass);
-static void gtk_plot_csurface_init 		(GtkPlotCSurface *data);
+static void gtk_plot_csurface_class_init 	(GtkPlotCSurfaceClass *klass, gpointer unused);
+static void gtk_plot_csurface_init 		(GtkPlotCSurface *data, gpointer unused);
 static void gtk_plot_csurface_destroy 		(GtkWidget *object);
 static void gtk_plot_csurface_get_property         (GObject      *object,
                                                  guint            prop_id,
@@ -143,7 +143,7 @@ gtk_plot_csurface_get_type (void)
 }
 
 static void
-gtk_plot_csurface_class_init (GtkPlotCSurfaceClass *klass)
+gtk_plot_csurface_class_init (GtkPlotCSurfaceClass *klass, gpointer unused)
 {
   GtkWidgetClass *object_class;
   GtkPlotDataClass *data_class;
@@ -314,6 +314,8 @@ gtk_plot_csurface_set_property (GObject      *object,
       case ARG_SUBLEVELS_COLOR:
         data->sublevels_line.color = *((GdkRGBA *)g_value_get_pointer(value));
         break;
+      default:
+	break;
     }
 }
 
@@ -367,7 +369,7 @@ update_data (GtkPlotData *data)
 }
 
 static void
-gtk_plot_csurface_init (GtkPlotCSurface *dataset)
+gtk_plot_csurface_init (GtkPlotCSurface *dataset, gpointer unused)
 {
   GtkPlotArray *dim;
 
@@ -700,7 +702,11 @@ gtk_plot_csurface_draw_lines(GtkPlotData *data)
         ntotal += 2;
         aux = aux->next;
       }
-      last = aux->next;
+
+      if (aux)
+	      last = aux->next;
+      else
+	      last = NULL;
 
       if(nlines == 0){ polygons = last; continue; }
 
@@ -900,24 +906,24 @@ gtk_plot_csurface_draw_lines(GtkPlotData *data)
         if(nxp > 0){
           gint j;
           for(j = 0; j < nxp; j++){
-            GtkPlotContourX aux = xp[j];
-            x = aux.type;
+            GtkPlotContourX auxx = xp[j];
+            x = auxx.type;
 
             if(x == 1){ 
-              if(p1->x >= aux.bb->x && p1->x <= aux.bb->x+aux.bb->width && p1->y >= aux.bb->y && p1->y <= aux.bb->y+aux.bb->height){
-                line[0] = aux.x1;
+              if(p1->x >= auxx.bb->x && p1->x <= auxx.bb->x+auxx.bb->width && p1->y >= auxx.bb->y && p1->y <= auxx.bb->y+auxx.bb->height){
+                line[0] = auxx.x1;
                 n = 1;
               } else {
                 if(n == 0) line[n++] = *p1;
-                line[n++] = aux.x1;
+                line[n++] = auxx.x1;
                 gtk_plot_pc_draw_lines(plot->pc, line, n); 
                 n = 0;
               }
             } else { /* x == 2 */
               if(n == 0) line[n++] = *p1;
-              line[n++] = aux.x1;
+              line[n++] = auxx.x1;
               gtk_plot_pc_draw_lines(plot->pc, line, n); 
-              line[0] = aux.x2;
+              line[0] = auxx.x2;
               n = 1;
             }
           }
@@ -1617,7 +1623,7 @@ gtk_plot_csurface_get_legend_size(GtkPlotData *data, gint *width, gint *height)
   if(data->legend)
     legend.text = data->legend;
   else
-    legend.text = "X";
+    legend.text = (char *)"X";
 
   *height = 0;
   *width = roundint(12 * m);
@@ -1659,7 +1665,7 @@ gtk_plot_csurface_draw_legend(GtkPlotData *data, gint x, gint y)
   if(data->legend)
     legend.text = data->legend;
   else
-    legend.text = "X";
+    legend.text = (char *)"X";
 
   gtk_plot_text_get_size(legend.text, legend.angle, legend.font,
                          roundint(legend.height * m), 
@@ -1769,6 +1775,8 @@ hsv_to_rgb (gdouble  h, gdouble  s, gdouble  v,
           *g = w;
           *b = q;
           break;
+	default:
+	  break;
       }
     }
 }
