@@ -37,8 +37,8 @@
 
 #define P_(string) string
 
-static void gtk_plot_flux_class_init 	(GtkPlotFluxClass *klass);
-static void gtk_plot_flux_init 		(GtkPlotFlux *data);
+static void gtk_plot_flux_class_init 	(GtkPlotFluxClass *klass, gpointer unused);
+static void gtk_plot_flux_init 		(GtkPlotFlux *data, gpointer unused);
 static void gtk_plot_flux_destroy 	(GtkWidget *data);
 static void gtk_plot_flux_get_property  (GObject      *object,
                                          guint        prop_id,
@@ -106,7 +106,7 @@ gtk_plot_flux_get_type (void)
 }
 
 static void
-gtk_plot_flux_class_init (GtkPlotFluxClass *klass)
+gtk_plot_flux_class_init (GtkPlotFluxClass *klass, gpointer unused)
 {
   GtkWidgetClass *object_class;
   GtkPlotDataClass *data_class;
@@ -272,7 +272,7 @@ gtk_plot_flux_class_init (GtkPlotFluxClass *klass)
 
 
 static void
-gtk_plot_flux_init (GtkPlotFlux *dataset)
+gtk_plot_flux_init (GtkPlotFlux *dataset, gpointer unused)
 {
   GdkRGBA black;
   GtkPlotArray *dim;
@@ -368,6 +368,8 @@ gtk_plot_flux_set_property (GObject      *object,
       case ARG_LABEL_SUFFIX:
         gtk_plot_flux_set_labels_suffix(data, g_value_get_string(value));
         break;
+      default:
+	break;
     }
 }
 
@@ -423,7 +425,7 @@ gtk_plot_flux_get_property (GObject      *object,
 }
 
 GtkWidget*
-gtk_plot_flux_new ()
+gtk_plot_flux_new (void)
 {
   GtkWidget *widget;
 
@@ -544,7 +546,7 @@ gtk_plot_flux_get_legend_size(GtkPlotData *data, gint *width, gint *height)
   if(data->legend)
     legend.text = data->legend;
   else
-    legend.text = "";
+    legend.text = (char *)"";
 
   *width = *height = 0;
   if(data->show_legend)
@@ -612,7 +614,7 @@ gtk_plot_flux_draw_legend(GtkPlotData *data, gint x, gint y)
   if(data->legend)
     legend.text = data->legend;
   else
-    legend.text = "";
+    legend.text = (char *)"";
 
   gtk_plot_text_get_size(legend.text, legend.angle, legend.font,
                          roundint(legend.height * m), 
@@ -740,6 +742,9 @@ gtk_plot_flux_draw_arrow(GtkPlotFlux *flux, gdouble x1, gdouble y1, gdouble x2,
       break;
     case GTK_PLOT_SYMBOL_FILLED:
       gtk_plot_pc_draw_polygon (plot->pc, TRUE, arrow, 3);
+      break;
+    default:
+      break;
   }
 }
 
