@@ -111,8 +111,7 @@ gel_read_plugin_list (void)
 	char *datadir;
 
 	/*free the previous list*/
-	g_slist_foreach (gel_plugin_list, (GFunc)free_plugin, NULL);
-	g_slist_free (gel_plugin_list);
+	g_slist_free_full (gel_plugin_list, (GDestroyNotify)free_plugin);
 	gel_plugin_list = NULL;
 	
 	datadir = gbr_find_data_dir (DATADIR);
@@ -244,7 +243,7 @@ gel_save_plugins (void)
 
 	if (genius_is_gui)
 		path = g_build_filename (g_get_home_dir (),
-					 ".gnome2", "genius", NULL);
+					 ".genius", "config-gui", NULL);
 	else
 		path = g_build_filename (g_get_home_dir (),
 					 ".genius", "config-cmdline", NULL);
@@ -295,10 +294,15 @@ gel_restore_plugins (void)
 	if (gel_plugin_list == NULL)
 		return;
 
-	if (genius_is_gui)
+	if (genius_is_gui) {
 		path = g_build_filename (g_get_home_dir (),
-					 ".gnome2", "genius", NULL);
-	else
+					 ".genius", "config-gui", NULL);
+		if (access (path, F_OK) != 0) {
+			g_free (path);
+			path = g_build_filename (g_get_home_dir (),
+						 ".gnome2", "genius", NULL);
+		}
+	} else
 		path = g_build_filename (g_get_home_dir (),
 					 ".genius", "config-cmdline", NULL);
 	cfg = ve_config_get (path);
